@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 
 use strict;
 use warnings;
@@ -177,7 +177,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
@@ -186,9 +186,11 @@ version 0.0600
   my $mcg = MIDI::Chord::Guitar->new;
 
   my $chords = $mcg->transform('D3', 'dim7');
-
   my $chord = $mcg->transform('D3', 'dim7', 0);
 
+  my $fingerings = $mcg->fingering('D3', 'dim7');
+  my $fingering = $mcg->fingering('D3', 'dim7', 0);
+
   # MIDI:
   #$score->n('wn', @$chord);
 
@@ -262,8 +264,7 @@ The default B<format> is C<midinum> but can be given as C<ISO> or
 C<midi> to return named notes with octaves.
 
 The order of the voicing variations of a chord is by fret position.
-So, the first variations are at lower frets.  Please use the above
-diagrams to figure out the exact neck positions.
+So, the first variations are at lower frets.
 
 Here is an example of the voicing CSV file which can be found with the
 B<voicing_file> attribute:
@@ -280,7 +281,7 @@ B<voicing_file> attribute:
   C7,xx1323-10,60,67,70,76,,
   ...
 
-Check out the link in the L</"SEE ALSO"> section for the chord shapes
+Check out the links in the L</"SEE ALSO"> section for the chord shapes
 used to create this.
 
 =head2 fingering
